@@ -28,8 +28,7 @@ class DiffModel(Protocol, Iterable):
     is_diff: bool
 
     def resolve(self, *args: Any, **kwargs: Any) -> DatabooksBase:
-        """Return a valid base object."""
-        ...
+        """Protocol method that returns a valid base object."""
 
 
 class BaseCells(UserList, Generic[T]):
@@ -40,8 +39,6 @@ class BaseCells(UserList, Generic[T]):
         """Return valid notebook cells from differences."""
         raise NotImplementedError
 
-    ...
-
 
 @overload
 def resolve(
